/*
 * The internal definitions
 *
 * Copyright (C) 2012-2019, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This software is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */

#if !defined( _LIBMODI_INTERNAL_DEFINITIONS_H )
#define _LIBMODI_INTERNAL_DEFINITIONS_H

#include <common.h>
#include <byte_stream.h>

#define LIBMODI_ENDIAN_BIG					_BYTE_STREAM_ENDIAN_BIG
#define LIBMODI_ENDIAN_LITTLE					_BYTE_STREAM_ENDIAN_LITTLE

/* Define HAVE_LOCAL_LIBMODI for local use of libmodi
 */
#if !defined( HAVE_LOCAL_LIBMODI )
#include <libmodi/definitions.h>

/* The definitions in <libmodi/definitions.h> are copied here
 * for local use of libmodi
 */
#else
#define LIBMODI_VERSION						20191025

/* The version string
 */
#define LIBMODI_VERSION_STRING					"20191025"

/* The access flags definitions
 * bit 1        set to 1 for read access
 * bit 2        set to 1 for write access
 * bit 3-8      not used
 */
enum LIBMODI_ACCESS_FLAGS
{
	LIBMODI_ACCESS_FLAG_READ				= 0x01,
/* Reserved: not supported yet */
	LIBMODI_ACCESS_FLAG_WRITE				= 0x02
};

/* The file access macros
 */
#define LIBMODI_OPEN_READ					( LIBMODI_ACCESS_FLAG_READ )
/* Reserved: not supported yet */
#define LIBMODI_OPEN_WRITE					( LIBMODI_ACCESS_FLAG_WRITE )
/* Reserved: not supported yet */
#define LIBMODI_OPEN_READ_WRITE					( LIBMODI_ACCESS_FLAG_READ | LIBMODI_ACCESS_FLAG_WRITE )

#endif /* !defined( HAVE_LOCAL_LIBMODI ) */

/* The image type definitions
 */
enum LIBMODI_IMAGE_TYPES
{
	LIBMODI_IMAGE_TYPE_UNKNOWN,
	LIBMODI_IMAGE_TYPE_SPARSE_BUNDLE,
	LIBMODI_IMAGE_TYPE_SPARSE_IMAGE,
	LIBMODI_IMAGE_TYPE_UDIF_COMPRESSED,
	LIBMODI_IMAGE_TYPE_UDIF_UNCOMPRESSED
};

/* The maximum number of cache entries defintions
 */
#define LIBMODI_MAXIMUM_CACHE_ENTRIES_DATA_BANDS		8

#endif /* !defined( _LIBMODI_INTERNAL_DEFINITIONS_H ) */

